//+------------------------------------------------------------------+
//|                                             Onno - Indicator.mq4 |
//|                                     Copyright 2019, Onno Rijkers |
//|                                            cfdaytrader@gmail.com |
//+------------------------------------------------------------------+
// Application settings
#property copyright "Copyright 2019, Onno Rijkers"
#property link      "cfdaytrader@gmail.com"
#property version   "1.00"

// Compiler settings
#property strict
#property indicator_chart_window
#property indicator_buffers            6
#property indicator_plots              6

// Include resources
#resource "Indicators\\SwingTrading.ex4"
#resource "Indicators\\##TSSystem.ex4"
#resource "Indicators\\5MinutesScalping-i1.ex4"
#resource "Indicators\\5MinutesScalping-i2.ex4"
#resource "Indicators\\5MinutesScalping-i3.ex4"
#resource "Indicators\\5MinutesScalping-i4.ex4"
#resource "Indicators\\5MinutesScalping-i5.ex4"

// Indicator default settings
#property indicator_color1             clrDodgerBlue
#property indicator_color2             clrRed
#property indicator_color3             clrDodgerBlue
#property indicator_color4             clrRed
#property indicator_color5             clrDodgerBlue
#property indicator_color6             clrRed
#property indicator_type1              DRAW_ARROW
#property indicator_type2              DRAW_ARROW
#property indicator_type3              DRAW_ARROW
#property indicator_type4              DRAW_ARROW
#property indicator_type5              DRAW_ARROW
#property indicator_type6              DRAW_ARROW

// Indicator buffers
double IndBuffer1[];                   // M2W up arrow
double IndBuffer2[];                   // M2W down arrow
double IndBuffer3[];                   // ST up arrow
double IndBuffer4[];                   // ST down arrow
double IndBuffer5[];                   // PN up arrow             (PN = Pantzos Nikolaos)
double IndBuffer6[];                   // PN down arrow

// Indicator parameters
extern double ArrowDistance = 0.0002;          // Arrow distance

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
{
   // Indicator buffers
   SetIndexBuffer(0, IndBuffer1);
   SetIndexBuffer(1, IndBuffer2);
   SetIndexBuffer(2, IndBuffer3);
   SetIndexBuffer(3, IndBuffer4);
   SetIndexBuffer(4, IndBuffer5);
   SetIndexBuffer(5, IndBuffer6);

   // Indicator arrow types
   SetIndexArrow(0, 233);
   SetIndexArrow(1, 234);
   SetIndexArrow(2, 200);
   SetIndexArrow(3, 202);
   SetIndexArrow(4, 241);
   SetIndexArrow(5, 242);

   // Hide indicators from Data Window
   SetIndexLabel(0, NULL);
   SetIndexLabel(1, NULL);
   SetIndexLabel(2, NULL);
   SetIndexLabel(3, NULL);
   SetIndexLabel(4, NULL);
   SetIndexLabel(5, NULL);

   return(INIT_SUCCEEDED);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int ratesTotal,
                const int prevCalculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tickVolume[],
                const long &volume[],
                const int &spread[])
{
   // Fill buffers
   int signal, upArrows, downArrows;
   int first = (prevCalculated > 0 ? ratesTotal - prevCalculated : ratesTotal);
   for (int i = first - 2; i >= 0; i--) {
      upArrows = 0;
      downArrows = 0;

      // Set M2W signal
      signal = GetM2WSignal(i);
      if (signal > 0) {
         upArrows++;
         IndBuffer1[i] = low[i] - ArrowDistance * upArrows;
         IndBuffer2[i] = EMPTY_VALUE;
      } else if (signal < 0) {
         downArrows++;
         IndBuffer1[i] = EMPTY_VALUE;
         IndBuffer2[i] = high[i] + ArrowDistance * downArrows;
      }

      // Set SwingTrader signal
      signal = GetSwingTraderSignal(i);
      if (signal > 0) {
         upArrows++;
         IndBuffer3[i] = low[i] - ArrowDistance * upArrows;
         IndBuffer4[i] = EMPTY_VALUE;
      } else if (signal < 0) {
         downArrows++;
         IndBuffer3[i] = EMPTY_VALUE;
         IndBuffer4[i] = high[i] + ArrowDistance * downArrows;
      }

      // Set PN signal
      signal = GetPNSignal(i);
      if (signal > 0) {
         upArrows++;
         IndBuffer5[i] = low[i] - ArrowDistance * upArrows;
         IndBuffer6[i] = EMPTY_VALUE;
      } else if (signal < 0) {
         downArrows++;
         IndBuffer5[i] = EMPTY_VALUE;
         IndBuffer6[i] = high[i] + ArrowDistance * downArrows;
      }
   }

   // Candles calculated
   return ratesTotal - 3;              // Always recalculate indicators for the last 3 candles
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int GetSwingTraderSignal(const int shift)
{
   // No signal detected
   return 0;
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int GetM2WSignal(const int shift)
{
   // No signal detected
   return 0;
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int GetPNSignal(const int shift)
{
   // Get indicator values
   double i1Up = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i1.ex4", 30, 0, false, false, 1, shift);
   double i1Down = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i1.ex4", 30, 0, false, false, 2, shift);
   double i2Up = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i2.ex4", 50, 0, false, false, 1, shift);
   double i2Down = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i2.ex4", 50, 0, false, false, 2, shift);
   double i3Up = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i3.ex4", 10, 0, false, false, 0, shift);
   double i3Down = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i3.ex4", 10, 0, false, false, 1, shift);
   double i4Up = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i4.ex4", 14, false, false, 2, shift);
   double i4Down = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i4.ex4", 14, false, false, 3, shift);
   double i5Up = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i5.ex4", 18, false, false, 0, shift);
   double i5Down = iCustom(Symbol(), PERIOD_CURRENT, "::Indicators\\5MinutesScalping-i5.ex4", 18, false, false, 1, shift);

   // Hide labels created by the indicators
   ObjectSet("Label1", OBJPROP_COLOR, clrNONE);
   ObjectSet("Label2", OBJPROP_COLOR, clrNONE);
   ObjectSet("Label3", OBJPROP_COLOR, clrNONE);
   ObjectSet("Label4", OBJPROP_COLOR, clrNONE);
   ObjectSet("Label5", OBJPROP_COLOR, clrNONE);

   // Determine signal
   if (i1Up != EMPTY_VALUE && i2Up != EMPTY_VALUE && i3Up != EMPTY_VALUE && i4Up != EMPTY_VALUE && i5Up != EMPTY_VALUE) {
      // Return up signal
      return 1;
   } else if (i1Down != EMPTY_VALUE && i2Down != EMPTY_VALUE && i3Down != EMPTY_VALUE && i4Down != EMPTY_VALUE && i5Down != EMPTY_VALUE) {
      // Return down signal
      return -1;
   }

   // No signal detected
   return 0;
}

//+------------------------------------------------------------------+
